@@ -7,17 +7,25 @@ OC.L10N.register(
     "Delete" : "Ta bort",
     "New" : "Ny",
     "New folder" : "Ny mappe",
+    "Delete folder" : "Slett mappe",
+    "Choose folder" : "Vel mappe",
     "Cancel" : "Avbryt",
+    "Shared with you" : "Shared with you",
+    "Files" : "Filer",
     "Import" : "Importer",
     "Export" : "Eksporter",
     "Title" : "Tittel",
     "Link" : "Lenkje",
     "Tags" : "Emneord",
     "Notes" : "Notat",
+    "Open file" : "Opne fil",
     "Owner" : "Owner",
     "Sharing" : "Deling",
     "Share link" : "Del lenkje",
     "Allow editing" : "Tillat endring",
+    "Allow resharing" : "Tillat vidaredeling",
+    "Link copied" : "Lenkje kopiert",
+    "Privacy" : "Personvern",
     "Folder" : "Mappe",
     "Save" : "Lagre"
 },
